@@ -1,7 +1,11 @@
 # vst12 functions ----
 
 test_that("vst01 functions with default argument value return expected result with test data", {
-  pre_data <- vst01_pre(syn_data)
+  proc_data <- dunlin::log_filter(
+    syn_data,
+    PARAMCD %in% c("DIABP", "SYSBP"), "advs"
+  )
+  pre_data <- vst01_pre(proc_data)
   raw_res <- vst01_main(pre_data)
   res <- cfbt01_post(raw_res)
   expect_snapshot(cat(export_as_txt(res, lpp = 200)))
@@ -10,6 +14,11 @@ test_that("vst01 functions with default argument value return expected result wi
 # vst01 ----
 
 test_that("run vst01 works as expected", {
-  res <- expect_silent(run(vst01, syn_data))
+  skip_on_os("windows")
+  proc_data <- dunlin::log_filter(
+    syn_data,
+    PARAMCD %in% c("DIABP", "SYSBP"), "advs"
+  )
+  res <- expect_silent(run(vst01, proc_data))
   expect_snapshot(cat(export_as_txt(res, lpp = 200)))
 })
